# Contributors

pyEQL was originally written by Prof. Ryan Kingsbury (@rkingsbury) and is primarily
developed and maintained by the Kingsbury Lab at Princeton University.

Other contributors, listed alphabetically, are:

* Kirill Pushkarev (@kirill-push)
* Dhruv Duseja (@DhruvDuseja)
* Andrew Rosen (@arosen93)
* Hernan Grecco (@hgrecco)

(If you think that your name belongs here, please let the maintainer know)
